@@ -1,11 +1,11 @@
 get.area <- function(mat, level.inf, level.sup=0, xlim=NULL, ylim=NULL) {
-	
+
 	# require(geosphere)
-	
+
 	if (!is(mat,"bathy") & !is(mat,"buffer")) stop("mat must be of class 'bathy' or 'buffer'")
-	
+
 	if (is(mat,"buffer")) mat <- mat[[1]]
-	
+
 	lon <- as.numeric(rownames(mat))
 	lat <- as.numeric(colnames(mat))
 
@@ -21,15 +21,15 @@ get.area <- function(mat, level.inf, level.sup=0, xlim=NULL, ylim=NULL) {
 	mat <- mat[x1b:x2b, y1b:y2b]
 	lon <- as.numeric(rownames(mat))
 	lat <- as.numeric(colnames(mat))
-	
+
 	cell.width <- (lon[2] - lon[1])
 	cell.height <- (lat[2] - lat[1])
-	
+
 	bathy2 <- ifelse(mat >= level.inf & mat <= level.sup, 1, 0)
 	cells <- apply(bathy2,2,sum)
 	cells <- cells[cells!=0]
 	c.lat <- as.numeric(names(cells))
-	
+
 	poly <- list()
 	for (i in 1:length(cells))
 		poly[[i]] <- rbind(	c(0,c.lat[i]),
@@ -37,8 +37,8 @@ get.area <- function(mat, level.inf, level.sup=0, xlim=NULL, ylim=NULL) {
 							c(cells[i]*cell.width,c.lat[i]+cell.height),
 							c(cells[i]*cell.width,c.lat[i])
 							)
-	
-	surf <- sum(sapply(poly,geosphere::areaPolygon,r=6371))
-	return <- list(Square.Km=surf, Area=bathy2, Lon=lon, Lat=lat)
-	
-}
\ No newline at end of file
+
+	surf <- sum(sapply(poly,geosphere::areaPolygon))
+	return <- list(Square.Km=surf/1000000, Area=bathy2, Lon=lon, Lat=lat)
+
+}
