@@ -1,7 +1,7 @@
-setSQL = function(bathy, header = TRUE, sep = ","){
+setSQL = function(bathy, header = TRUE, sep = ",", db.name = "bathy_db"){
 
 	# prepare ("connect") SQL database
-	con <- DBI::dbConnect(RSQLite::SQLite(), dbname = "bathy_db")
+	con <- DBI::dbConnect(RSQLite::SQLite(), dbname = db.name)
 	# data frame -> database table.
 	DBI::dbWriteTable(con, name="bathy_db", value=bathy, header=header, sep=sep)
 
